Learn R Programming

fqar (version 0.5.6)

download_transect: Download a single floristic quality transect assessment

Description

download_transect() retrieves a specified floristic quality transect assessment from universalfqa.org. ID numbers for transect assessments in various databases can be found using the index_fqa_transects() function.

Usage

download_transect(transect_id, timeout = 4)

Value

An untidy data frame in the original format of the Universal FQA website, except that the transect id number has been appended in the first row.. Use transect_glance() for a tidy summary, transect_phys() for a physiognometric overview, and

transect_inventory() for species-level data.

Arguments

transect_id

A numeric identifier of the desired floristic quality transect assessment, as specified by universalfqa.org. ID numbers for transect assessments in specified databases can be viewed with the index_fqa_transects() function.

timeout

Number of seconds to query UniversalFQA before timing out.

Examples

Run this code
# \donttest{
databases <- index_fqa_databases() # Database 1 is the original 1994 Chicago edition.
chicago_transects <- index_fqa_transects(1) # CBG Sand prairie swale fen A has id number 5932.
cbg <- download_transect(5932, timeout = 10)
# }

Run the code above in your browser using DataLab