Learn R Programming

fqar (version 0.5.6)

download_transect_list: Download multiple floristic quality transect assessments

Description

download_transect_list() searches a specified floristic quality assessment database and retrieves all matches from universalfqa.org. Download speeds from that website may be slow, causing delays in the evaluation of this function.

Usage

download_transect_list(database_id, ..., timeout = 4)

Value

A list of data frames matching the search criteria. Each is an untidy data frame in the original format of the Universal FQA website. Use

transect_list_glance() for a tidy summary.

Arguments

database_id

Numeric identifier of the desired floristic quality assessment database, as specified by universalfqa.org. Database id numbers can be viewed with the index_fqa_databases() function.

...

dplyr-style filtering criteria for the desired transect assessments. The following variables may be used:

  • id (numeric)

  • assessment (character)

  • date (date)

  • site (character)

  • practitioner (character)

timeout

Number of seconds to query UniversalFQA before timing out.

Examples

Run this code
# \donttest{
databases <- index_fqa_databases() # Database 1 is the original 1994 Chicago edition.
dupont <- download_transect_list(1, site == "DuPont Natural Area")
# }

Run the code above in your browser using DataLab