Learn R Programming

fqar (version 0.5.6)

index_fqa_transects: List all available public floristic quality transect assessments

Description

For any given database, index_fqa_transects() produces a data frame of all floristic quality transect assessments publicly available at universalfqa.org.

Usage

index_fqa_transects(database_id, timeout = 4)

Value

A data frame with 5 columns:

  • id (numeric)

  • assessment (character)

  • date (date)

  • site (character)

  • practitioner (character)

Arguments

database_id

A numeric identifier of the desired database, as specified by universalfqa.org. The id numbers can be viewed with the index_fqa_databases() function.

timeout

Number of seconds to query UniversalFQA before timing out.

Examples

Run this code
# \donttest{
databases <- index_fqa_databases() # The 2017 Chicago database has id_number 149
chicago_2017_transects <- index_fqa_transects(149)
# }

Run the code above in your browser using DataLab