species_common_name: Common name of a species in a specified database
Description
species_common name() accepts the scientific name of a species and a
database inventory and returns the common name of that species. Either a numeric
database ID from universalfqa.org or a
homemade inventory with the same format may be specified.