Learn R Programming

fqar (version 0.5.6)

transect_glance: Obtain tidy summary information for a floristic quality transect assessment

Description

transect_glance() tidies a floristic quality transect assessment data set obtained from universalfqa.org.

Usage

transect_glance(data_set)

Value

A data frame with 1 row and 55 columns:

  • transect_id (numeric)

  • title (character)

  • date (date)

  • site_name (character)

  • city (character)

  • county (character)

  • state (character)

  • country (character)

  • omernik_level_three_ecoregion (character)

  • fqa_db_region (character)

  • fqa_db_publication_year (character)

  • fqa_db_description (character)

  • fqa_db_selection_name (character)

  • custom_fqa_db_name (character)

  • custom_fqa_db_description (character)

  • practitioner (character)

  • latitude (character)

  • longitude (character)

  • community_code (character)

  • community_name (character)

  • community_type_notes (character)

  • weather_notes (character)

  • duration_notes (character)

  • environment_description (character)

  • other_notes (character)

  • transect_plot_type (character)

  • plot_size (numeric) Plot size in square meters

  • quadrat_subplot_size (numeric) Quadrat or subplot size in square meters

  • transect_length (numeric) Transect length in meters

  • sampling_design_description (character)

  • cover_method (character)

  • private_public (character)

  • total_mean_c (numeric)

  • cover_weighted_mean_c (numeric)

  • native_mean_c (numeric)

  • total_fqi (numeric)

  • native_fqi (numeric)

  • cover_weighted_fqi (numeric)

  • cover_weighted_native_fqi (numeric)

  • adjusted_fqi (numeric)

  • c_value_zero (numeric) Percent of c-values 0

  • c_value_low (numeric) Percent of c-values 1-3

  • c_value_mid (numeric) Percent of c-values 4-6

  • c_value_high (numeric) Percent of c-values 7-10

  • total_species (numeric)

  • native_species (numeric)

  • non_native_species (numeric)

  • mean_wetness (numeric)

  • native_mean_wetness (numeric)

  • annual (numeric)

  • perennial (numeric)

  • biennial (numeric)

  • native_annual (numeric)

  • native_perennial (numeric)

  • native_biennial (numeric)

Arguments

data_set

A data set downloaded from universalfqa.org either manually or using download_transect().

Examples

Run this code
# While transect_glance can be used with a .csv file downloaded manually
# from the universal FQA website, it is most typically used in combination
# with download_transect().

# \donttest{
tyler <- download_transect(6352)
transect_glance(tyler)
# }

Run the code above in your browser using DataLab