transect_phys: Obtain physiognometric information for a floristic quality...

View source: R/transect_phys.R

transect_physR Documentation

Obtain physiognometric information for a floristic quality transect assessment

Description

transect_phys() returns a data frame with physiognometric information for a floristic quality transect assessment obtained from universalfqa.org.

Usage

transect_phys(data_set)

Arguments

data_set

A data set downloaded from universalfqa.org either manually or using download_transect().

Value

A data frame with 6 columns:

  • physiognomy (character)

  • frequency (numeric)

  • coverage (numeric)

  • relative_frequency_percent (numeric)

  • relative_coverage_percent (numeric)

  • relative_importance_value_percent (numeric)

Examples

# While transect_phys can be used with a .csv file downloaded
# manually from the universal FQA website, it is most typically used
# in combination with download_transect().


tyler <- download_transect(6352)
transect_phys(tyler)



fqar documentation built on June 22, 2025, 1:06 a.m.